## [2.3.0-beta.12](https://github.com/f-aguzzi/tesi/compare/v2.3.0-beta.11...v2.3.0-beta.12) (2024-06-11)


### Bug Fixes

* **tests:** test case for BaseDataModel import/export ([0817547](https://github.com/f-aguzzi/tesi/commit/081754777e0b9be2a7ffe9b86b403a4538a682e1))

## [2.3.0-beta.11](https://github.com/f-aguzzi/tesi/compare/v2.3.0-beta.10...v2.3.0-beta.11) (2024-06-11)


### Features

* **LLDF:** print table name in graphs ([1d78181](https://github.com/f-aguzzi/tesi/commit/1d78181a7f066e63c8eebcbcfee019a076882fc6))


### Bug Fixes

* error in condition in extended split tests ([5b56d15](https://github.com/f-aguzzi/tesi/commit/5b56d15787e95830dcc3937d21af5b8e93af8219))


### Docs

* updated case studies ([f838c2e](https://github.com/f-aguzzi/tesi/commit/f838c2e8d095f07e8c7f64e3776f072be6293728))

## [2.3.0-beta.10](https://github.com/f-aguzzi/tesi/compare/v2.3.0-beta.9...v2.3.0-beta.10) (2024-06-11)


### Features

* **BaseDataModel:** subscript sample selection ([0830397](https://github.com/f-aguzzi/tesi/commit/08303978b5773f16fbbd98c30b7751959d759558))

## [2.3.0-beta.9](https://github.com/f-aguzzi/tesi/compare/v2.3.0-beta.8...v2.3.0-beta.9) (2024-06-11)


### Bug Fixes

* **LR:** add special case for binary classifiers ([8da46b7](https://github.com/f-aguzzi/tesi/commit/8da46b7ecb5f2708fff9d6088eb484ce0ad13f6f))
* **LLDF:** wrong data concatenation ([9bb5f93](https://github.com/f-aguzzi/tesi/commit/9bb5f9346d4ee19b11deaaf7567e4dd9538c3fd7))

## [2.3.0-beta.8](https://github.com/f-aguzzi/tesi/compare/v2.3.0-beta.7...v2.3.0-beta.8) (2024-06-11)


### Bug Fixes

* **LLDF:** graph printing issues ([6eb9fba](https://github.com/f-aguzzi/tesi/commit/6eb9fba431339e430145d1d3dbc54ee9d6f6a802))
* **LLDF:** import column names checking ([f51b11c](https://github.com/f-aguzzi/tesi/commit/f51b11c9981f9f7a26d688ab1954003e8be443a6))

## [2.3.0-beta.7](https://github.com/f-aguzzi/tesi/compare/v2.3.0-beta.6...v2.3.0-beta.7) (2024-06-11)


### Bug Fixes

* **PCA:** conditions of reduce exception raising ([1f74220](https://github.com/f-aguzzi/tesi/commit/1f74220039b0f59374f568ea5744dc3728a28a13))

## [2.3.0-beta.6](https://github.com/f-aguzzi/tesi/compare/v2.3.0-beta.5...v2.3.0-beta.6) (2024-06-11)


### Features

* **PCA:** added reduce method ([1ad418e](https://github.com/f-aguzzi/tesi/commit/1ad418eec712522038dab118744c60a0dbf8f47f))

## [2.3.0-beta.5](https://github.com/f-aguzzi/tesi/compare/v2.3.0-beta.4...v2.3.0-beta.5) (2024-06-11)


### Features

* add from_file classmethod to BaseClassifier ([9478f88](https://github.com/f-aguzzi/tesi/commit/9478f88dbf58df1c5e06fbf1a996b936b8b174f9))
* **PCA:** model import and export ([15e13f1](https://github.com/f-aguzzi/tesi/commit/15e13f13897073f79373924fb4658e3ecb590085))

## [2.3.0-beta.4](https://github.com/f-aguzzi/tesi/compare/v2.3.0-beta.3...v2.3.0-beta.4) (2024-06-11)


### Features

* PCA rescaled_data property ([9eb9301](https://github.com/f-aguzzi/tesi/commit/9eb93015e4fa936f93de46cf25c8de6d7898440e))

## [2.3.0-beta.3](https://github.com/f-aguzzi/tesi/compare/v2.3.0-beta.2...v2.3.0-beta.3) (2024-06-08)


### Bug Fixes

* **CI/CD:** conditional workflow run ([74d308b](https://github.com/f-aguzzi/tesi/commit/74d308be2f4c1750e5d6f8bcbda889e895a828fa))

## [2.3.0-beta.2](https://github.com/f-aguzzi/tesi/compare/v2.3.0-beta.1...v2.3.0-beta.2) (2024-06-08)


### Bug Fixes

* **lldf:** wrong exception type on export with invalid format ([3842ed9](https://github.com/f-aguzzi/tesi/commit/3842ed9d1f003c19565ef1a4cbd8e5544f6476e4))

## [2.3.0-beta.1](https://github.com/f-aguzzi/tesi/compare/v2.2.0...v2.3.0-beta.1) (2024-06-08)


### Features

* added json and csv support for table import/export ([392933a](https://github.com/f-aguzzi/tesi/commit/392933a09d7333e81d99feb6a5b67bd5e30051d4))


### Docs

* version 2.3.0 ([a10d464](https://github.com/f-aguzzi/tesi/commit/a10d46437e5c6d3fe29d3b4fded01e87e352687e))

## [2.2.0](https://github.com/f-aguzzi/tesi/compare/v2.1.0...v2.2.0) (2024-06-07)


### Features

* excel import with user-defined schema ([f0d0d74](https://github.com/f-aguzzi/tesi/commit/f0d0d74efa04711d89bafa2082c352f117fd0680))


### Docs

* update to version 2.2.0 ([ebff95d](https://github.com/f-aguzzi/tesi/commit/ebff95d7cf00d7c86d987d113543631acc0a0113))


### CI

* **release:** 2.2.0-beta.1 [skip ci] ([4249066](https://github.com/f-aguzzi/tesi/commit/424906654381225681761d3d62e7bd0ac93d3c79))

## [2.2.0-beta.1](https://github.com/f-aguzzi/tesi/compare/v2.1.0...v2.2.0-beta.1) (2024-06-07)


### Features

* excel import with user-defined schema ([f0d0d74](https://github.com/f-aguzzi/tesi/commit/f0d0d74efa04711d89bafa2082c352f117fd0680))


### Docs

* update to version 2.2.0 ([ebff95d](https://github.com/f-aguzzi/tesi/commit/ebff95d7cf00d7c86d987d113543631acc0a0113))

## [2.1.0](https://github.com/f-aguzzi/tesi/compare/v2.0.0...v2.1.0) (2024-06-07)


### Features

* **import/export:** fully functional file dumping ([e1d0044](https://github.com/f-aguzzi/tesi/commit/e1d004448afd86f4ffa2ed4b87629e6798ef41b2))


### chore

* **license:** add GPLv3 license ([3fdd0b8](https://github.com/f-aguzzi/tesi/commit/3fdd0b87b6587b7413dd36f5101d37a5d712e7d7))
* **docs:** version 2.1.0 ([3601750](https://github.com/f-aguzzi/tesi/commit/3601750fab58414dfe565abb7ecab57630b61a31))


### Docs

* add new information ([be7c262](https://github.com/f-aguzzi/tesi/commit/be7c2624710d6dbf4f0d320e451e5001853560cc))


### CI

* **release:** 2.1.0-beta.1 [skip ci] ([39c5542](https://github.com/f-aguzzi/tesi/commit/39c55420774090231db53ccbacf52ffbbc53009e))

## [2.1.0-beta.1](https://github.com/f-aguzzi/tesi/compare/v2.0.0...v2.1.0-beta.1) (2024-06-05)


### Features

* **import/export:** fully functional file dumping ([e1d0044](https://github.com/f-aguzzi/tesi/commit/e1d004448afd86f4ffa2ed4b87629e6798ef41b2))


### chore

* **license:** add GPLv3 license ([3fdd0b8](https://github.com/f-aguzzi/tesi/commit/3fdd0b87b6587b7413dd36f5101d37a5d712e7d7))

## [2.0.0](https://github.com/f-aguzzi/tesi/compare/v1.2.0...v2.0.0) (2024-06-04)


### ⚠ BREAKING CHANGES

* added base class for classifiers, models, settings

### Features

* added base class for classifiers, models, settings ([4af5d47](https://github.com/f-aguzzi/tesi/commit/4af5d4778d28021dcd2e23f00fc5810ae178769d))
* **LDA:** autodetect components from PCADataModel ([a59cd54](https://github.com/f-aguzzi/tesi/commit/a59cd545e9926de94117f2a46be5801c24271ba8))
* made LR inherit from BaseClassifier ([d06a7db](https://github.com/f-aguzzi/tesi/commit/d06a7db270a99517a6445c94bdfacc1901e90121))


### Bug Fixes

* lda and lr_tests missing arguments ([280159d](https://github.com/f-aguzzi/tesi/commit/280159d8208f46a2a843e9eeae60d82114e15261))


### Docs

* fix broken github pages build ([862ddf6](https://github.com/f-aguzzi/tesi/commit/862ddf6557973229ec9b85830b677822db0f9da7))
* fix wrong version number ([a0eb4e6](https://github.com/f-aguzzi/tesi/commit/a0eb4e6110dc25a5a8a4e6e72ff7ba02c05f6a14))
* new blog post ([afed9f7](https://github.com/f-aguzzi/tesi/commit/afed9f7620d06559892a517daef4f78192d3f3e2))
* new cookbook section ([fd9a243](https://github.com/f-aguzzi/tesi/commit/fd9a2435469bdcf0457909ec3424ce1af5b118a9))
* new version ([7c96050](https://github.com/f-aguzzi/tesi/commit/7c96050e20382fdd2312584dd0cf8ee091329181))
* update examples ([c919596](https://github.com/f-aguzzi/tesi/commit/c919596c94a7fd0c54548027d05c857c758054c9))
* updated docusaurus with versioning ([0b6d5c4](https://github.com/f-aguzzi/tesi/commit/0b6d5c4319f371a757ad0fc3a142e2eb1d959137)), closes [#33](https://github.com/f-aguzzi/tesi/issues/33)


### Refactor

* moved prediction into base class ([57a3497](https://github.com/f-aguzzi/tesi/commit/57a349743964db553aa6cea425631022c37920b3))
* **lldf:** switch arguments in constructor call ([fcf7471](https://github.com/f-aguzzi/tesi/commit/fcf7471ba519ceed7747f48895421e932506b835))


### CI

* **release:** 2.0.0-beta.1 [skip ci] ([6c4af27](https://github.com/f-aguzzi/tesi/commit/6c4af27e2d24a62ea91d4701bd1100ad2ea51801)), closes [#33](https://github.com/f-aguzzi/tesi/issues/33)
* **release:** 2.0.0-beta.2 [skip ci] ([c6892a9](https://github.com/f-aguzzi/tesi/commit/c6892a9d4f8e6e0cece469139c6c834e60d1f7bf))
* **release:** 2.0.0-beta.3 [skip ci] ([b9bd5e0](https://github.com/f-aguzzi/tesi/commit/b9bd5e0be28eeb3b9ea53a6ddb871a4532685184))
* **release:** 2.0.0-beta.4 [skip ci] ([330ad59](https://github.com/f-aguzzi/tesi/commit/330ad59b45e2ca435f0159c7a2ff656ca2e78570))

## [2.0.0-beta.4](https://github.com/f-aguzzi/tesi/compare/v2.0.0-beta.3...v2.0.0-beta.4) (2024-06-04)


### Bug Fixes

* lda and lr_tests missing arguments ([280159d](https://github.com/f-aguzzi/tesi/commit/280159d8208f46a2a843e9eeae60d82114e15261))


### Docs

* new blog post ([afed9f7](https://github.com/f-aguzzi/tesi/commit/afed9f7620d06559892a517daef4f78192d3f3e2))

## [2.0.0-beta.3](https://github.com/f-aguzzi/tesi/compare/v2.0.0-beta.2...v2.0.0-beta.3) (2024-06-04)


### Features

* **LDA:** autodetect components from PCADataModel ([a59cd54](https://github.com/f-aguzzi/tesi/commit/a59cd545e9926de94117f2a46be5801c24271ba8))


### Docs

* fix wrong version number ([a0eb4e6](https://github.com/f-aguzzi/tesi/commit/a0eb4e6110dc25a5a8a4e6e72ff7ba02c05f6a14))
* update examples ([c919596](https://github.com/f-aguzzi/tesi/commit/c919596c94a7fd0c54548027d05c857c758054c9))


### Refactor

* moved prediction into base class ([57a3497](https://github.com/f-aguzzi/tesi/commit/57a349743964db553aa6cea425631022c37920b3))
* **lldf:** switch arguments in constructor call ([fcf7471](https://github.com/f-aguzzi/tesi/commit/fcf7471ba519ceed7747f48895421e932506b835))

## [2.0.0-beta.2](https://github.com/f-aguzzi/tesi/compare/v2.0.0-beta.1...v2.0.0-beta.2) (2024-06-04)


### Features

* made LR inherit from BaseClassifier ([d06a7db](https://github.com/f-aguzzi/tesi/commit/d06a7db270a99517a6445c94bdfacc1901e90121))


### Docs

* new version ([7c96050](https://github.com/f-aguzzi/tesi/commit/7c96050e20382fdd2312584dd0cf8ee091329181))

## [2.0.0-beta.1](https://github.com/f-aguzzi/tesi/compare/v1.2.0...v2.0.0-beta.1) (2024-06-04)


### ⚠ BREAKING CHANGES

* added base class for classifiers, models, settings

### Features

* added base class for classifiers, models, settings ([4af5d47](https://github.com/f-aguzzi/tesi/commit/4af5d4778d28021dcd2e23f00fc5810ae178769d))


### Docs

* fix broken github pages build ([862ddf6](https://github.com/f-aguzzi/tesi/commit/862ddf6557973229ec9b85830b677822db0f9da7))
* new cookbook section ([fd9a243](https://github.com/f-aguzzi/tesi/commit/fd9a2435469bdcf0457909ec3424ce1af5b118a9))
* updated docusaurus with versioning ([0b6d5c4](https://github.com/f-aguzzi/tesi/commit/0b6d5c4319f371a757ad0fc3a142e2eb1d959137)), closes [#33](https://github.com/f-aguzzi/tesi/issues/33)

## [1.2.0](https://github.com/f-aguzzi/tesi/compare/v1.1.3...v1.2.0) (2024-06-03)


### Features

* graphing and multi-table in LLDF ([c450767](https://github.com/f-aguzzi/tesi/commit/c4507672fb502dfd5d9b0994ff461387ff5a3acc))


### Bug Fixes

* docs workflow, dependency clashes, demos ([a994940](https://github.com/f-aguzzi/tesi/commit/a994940a6bf115ea02054754fb3b237977a4e3aa)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)
* docs workflow, dependency clashes, demos ([6f72ec4](https://github.com/f-aguzzi/tesi/commit/6f72ec4a0c51902e05e468b6d6f79042a3bc73e5)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)
* gh pages workflow ([49c6bda](https://github.com/f-aguzzi/tesi/commit/49c6bdabf757073e87e0c7b0c98eb4d0ef843f78))


### Docs

* add documentation versioning [skip ci] ([ee0b7ab](https://github.com/f-aguzzi/tesi/commit/ee0b7ab915501d30d12ed6542535434265f0bd61))
* added version 1.2 ([3fcd0cc](https://github.com/f-aguzzi/tesi/commit/3fcd0cc7abdb5daa201c74ba959340711506e1f0))


### CI

* **release:** 1.1.1-beta.2 [skip ci] ([a0519e7](https://github.com/f-aguzzi/tesi/commit/a0519e71d2bc75830ce027bdb11589a0762905a8)), closes [#25](https://github.com/f-aguzzi/tesi/issues/25)
* **release:** 1.1.1-beta.3 [skip ci] ([4dc43c6](https://github.com/f-aguzzi/tesi/commit/4dc43c6f2e7ec6e34e6adfb5ad1b2aacaa3731e2)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)
* **release:** 1.1.2-beta.1 [skip ci] ([a903084](https://github.com/f-aguzzi/tesi/commit/a9030846e88a15dfd9ec8a9418e59098ef4e439c)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28) [#25](https://github.com/f-aguzzi/tesi/issues/25) [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)
* **release:** 1.1.2-beta.2 [skip ci] ([c23bcb0](https://github.com/f-aguzzi/tesi/commit/c23bcb0e833ed10ff7665f56edd82c0617152156)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)
* **release:** 1.1.2-beta.3 [skip ci] ([0bcdf85](https://github.com/f-aguzzi/tesi/commit/0bcdf851d60b16c3e4ced0f562149490d6bcbcbe))
* **release:** 1.1.4-beta.1 [skip ci] ([d1e06cc](https://github.com/f-aguzzi/tesi/commit/d1e06cc4238c3e4f1b86ce4e8ab7e3eac6c5d1c6)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28) [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28) [#25](https://github.com/f-aguzzi/tesi/issues/25) [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28) [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28) [#25](https://github.com/f-aguzzi/tesi/issues/25) [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28) [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)
* **release:** 1.2.0-beta.1 [skip ci] ([b08fa39](https://github.com/f-aguzzi/tesi/commit/b08fa3970d537a19072b70edb2275488d160d69f))

## [1.2.0-beta.1](https://github.com/f-aguzzi/tesi/compare/v1.1.4-beta.1...v1.2.0-beta.1) (2024-06-03)


### Features

* graphing and multi-table in LLDF ([c450767](https://github.com/f-aguzzi/tesi/commit/c4507672fb502dfd5d9b0994ff461387ff5a3acc))

## [1.1.4-beta.1](https://github.com/f-aguzzi/tesi/compare/v1.1.3...v1.1.4-beta.1) (2024-06-03)


### Bug Fixes

* docs workflow, dependency clashes, demos ([a994940](https://github.com/f-aguzzi/tesi/commit/a994940a6bf115ea02054754fb3b237977a4e3aa)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)
* docs workflow, dependency clashes, demos ([6f72ec4](https://github.com/f-aguzzi/tesi/commit/6f72ec4a0c51902e05e468b6d6f79042a3bc73e5)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)
* gh pages workflow ([49c6bda](https://github.com/f-aguzzi/tesi/commit/49c6bdabf757073e87e0c7b0c98eb4d0ef843f78))


### Docs

* add documentation versioning [skip ci] ([ee0b7ab](https://github.com/f-aguzzi/tesi/commit/ee0b7ab915501d30d12ed6542535434265f0bd61))
* added version 1.2 ([3fcd0cc](https://github.com/f-aguzzi/tesi/commit/3fcd0cc7abdb5daa201c74ba959340711506e1f0))


### CI

* **release:** 1.1.1-beta.2 [skip ci] ([a0519e7](https://github.com/f-aguzzi/tesi/commit/a0519e71d2bc75830ce027bdb11589a0762905a8)), closes [#25](https://github.com/f-aguzzi/tesi/issues/25)
* **release:** 1.1.1-beta.3 [skip ci] ([4dc43c6](https://github.com/f-aguzzi/tesi/commit/4dc43c6f2e7ec6e34e6adfb5ad1b2aacaa3731e2)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)
* **release:** 1.1.2-beta.1 [skip ci] ([a903084](https://github.com/f-aguzzi/tesi/commit/a9030846e88a15dfd9ec8a9418e59098ef4e439c)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28) [#25](https://github.com/f-aguzzi/tesi/issues/25) [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)
* **release:** 1.1.2-beta.2 [skip ci] ([c23bcb0](https://github.com/f-aguzzi/tesi/commit/c23bcb0e833ed10ff7665f56edd82c0617152156)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)
* **release:** 1.1.2-beta.3 [skip ci] ([0bcdf85](https://github.com/f-aguzzi/tesi/commit/0bcdf851d60b16c3e4ced0f562149490d6bcbcbe))

## [1.1.3](https://github.com/f-aguzzi/tesi/compare/v1.1.2...v1.1.3) (2024-05-29)


### Bug Fixes

* numpy dependency clash ([cab6371](https://github.com/f-aguzzi/tesi/commit/cab6371b993b4019cb2d223d1e20759ab642c30a))

## [1.1.2](https://github.com/f-aguzzi/tesi/compare/v1.1.1...v1.1.2) (2024-05-29)


### Bug Fixes

* updated paths and triggers in workflows ([6a5fd55](https://github.com/f-aguzzi/tesi/commit/6a5fd55592446e7fcbf99fc390562c0574771cb2))

## [1.1.2-beta.3](https://github.com/f-aguzzi/tesi/compare/v1.1.2-beta.2...v1.1.2-beta.3) (2024-05-29)


### Bug Fixes

* gh pages workflow ([49c6bda](https://github.com/f-aguzzi/tesi/commit/49c6bdabf757073e87e0c7b0c98eb4d0ef843f78))

## [1.1.2-beta.2](https://github.com/f-aguzzi/tesi/compare/v1.1.2-beta.1...v1.1.2-beta.2) (2024-05-29)


### Bug Fixes

* docs workflow, dependency clashes, demos ([a994940](https://github.com/f-aguzzi/tesi/commit/a994940a6bf115ea02054754fb3b237977a4e3aa)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)

## [1.1.2-beta.1](https://github.com/f-aguzzi/tesi/compare/v1.1.1...v1.1.2-beta.1) (2024-05-29)


### Bug Fixes

* docs workflow, dependency clashes, demos ([6f72ec4](https://github.com/f-aguzzi/tesi/commit/6f72ec4a0c51902e05e468b6d6f79042a3bc73e5)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)


### CI

* **release:** 1.1.1-beta.2 [skip ci] ([a0519e7](https://github.com/f-aguzzi/tesi/commit/a0519e71d2bc75830ce027bdb11589a0762905a8)), closes [#25](https://github.com/f-aguzzi/tesi/issues/25)
* **release:** 1.1.1-beta.3 [skip ci] ([4dc43c6](https://github.com/f-aguzzi/tesi/commit/4dc43c6f2e7ec6e34e6adfb5ad1b2aacaa3731e2)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)

## [1.1.1-beta.3](https://github.com/f-aguzzi/tesi/compare/v1.1.1-beta.2...v1.1.1-beta.3) (2024-05-29)


### Bug Fixes


* docs workflow, dependency clashes, demos ([6f72ec4](https://github.com/f-aguzzi/tesi/commit/6f72ec4a0c51902e05e468b6d6f79042a3bc73e5)), closes [#29](https://github.com/f-aguzzi/tesi/issues/29) [#28](https://github.com/f-aguzzi/tesi/issues/28)

## [1.1.1-beta.2](https://github.com/f-aguzzi/tesi/compare/v1.1.1-beta.1...v1.1.1-beta.2) (2024-05-24)


### Bug Fixes

* wrong training procedure in SVM ([#25](https://github.com/f-aguzzi/tesi/issues/25)) ([7f25487](https://github.com/f-aguzzi/tesi/commit/7f254876fcdbd2ba5c46278d31eb851a50659e8f))
* wrong training procedure in SVM ([74d1741](https://github.com/f-aguzzi/tesi/commit/74d1741743f53eea6cc2d9002005c6426bf4f0d0))
* wrong training procedure in SVM ([#25](https://github.com/f-aguzzi/tesi/issues/25)) ([7f25487](https://github.com/f-aguzzi/tesi/commit/7f254876fcdbd2ba5c46278d31eb851a50659e8f))


### CI

* **release:** 1.1.0-beta.3 [skip ci] ([96988ac](https://github.com/f-aguzzi/tesi/commit/96988acbfd0f015c03385f74f14ea26e98a9b4b2))
* **release:** 1.1.1-beta.1 [skip ci] ([a6e41a8](https://github.com/f-aguzzi/tesi/commit/a6e41a88456fc8224c0864de40eb2233c0c30329))


## [1.1.1-beta.1](https://github.com/f-aguzzi/tesi/compare/v1.1.0...v1.1.1-beta.1) (2024-05-23)


### Bug Fixes

* wrong training procedure in SVM ([74d1741](https://github.com/f-aguzzi/tesi/commit/74d1741743f53eea6cc2d9002005c6426bf4f0d0))


### CI

* **release:** 1.1.0-beta.3 [skip ci] ([96988ac](https://github.com/f-aguzzi/tesi/commit/96988acbfd0f015c03385f74f14ea26e98a9b4b2))

## [1.1.0-beta.3](https://github.com/f-aguzzi/tesi/compare/v1.1.0-beta.2...v1.1.0-beta.3) (2024-05-23)


### Features

* beartype integration ([2f823ce](https://github.com/f-aguzzi/tesi/commit/2f823cebee0cb8006523d9e0d6aaa673484bd928)), closes [#7](https://github.com/f-aguzzi/tesi/issues/7)


### Bug Fixes


* wrong training procedure in SVM ([74d1741](https://github.com/f-aguzzi/tesi/commit/74d1741743f53eea6cc2d9002005c6426bf4f0d0))

* add missing checks to LLDFSettings ([3d57752](https://github.com/f-aguzzi/tesi/commit/3d577527eefd0b183a66c378d53cb1f1ee506343)), closes [#20](https://github.com/f-aguzzi/tesi/issues/20)


### chore

* **thesis:** set up build system (merge from [#22](https://github.com/f-aguzzi/tesi/issues/22)) ([0b13ed3](https://github.com/f-aguzzi/tesi/commit/0b13ed346448f0eeefecbc6fd051eb7c98919650))


### Refactor

* extract split tests and graphs (merge [#23](https://github.com/f-aguzzi/tesi/issues/23)) ([6865c88](https://github.com/f-aguzzi/tesi/commit/6865c88d70b650de5e8440807b0194022a15dc0e))


### CI

* **release:** 1.1.0-beta.1 [skip ci] ([2deffcc](https://github.com/f-aguzzi/tesi/commit/2deffcc4c8a29d09a4a644558e491d770f71f6dc)), closes [#7](https://github.com/f-aguzzi/tesi/issues/7)
* **release:** 1.1.0-beta.2 [skip ci] ([25704dc](https://github.com/f-aguzzi/tesi/commit/25704dc4eb0cbc249bbf85611c5dfe257ebccc30)), closes [#20](https://github.com/f-aguzzi/tesi/issues/20) [#22](https://github.com/f-aguzzi/tesi/issues/22) [#23](https://github.com/f-aguzzi/tesi/issues/23)


## [1.1.0-beta.2](https://github.com/f-aguzzi/tesi/compare/v1.1.0-beta.1...v1.1.0-beta.2) (2024-05-20)


### Bug Fixes

* add missing checks to LLDFSettings ([3d57752](https://github.com/f-aguzzi/tesi/commit/3d577527eefd0b183a66c378d53cb1f1ee506343)), closes [#20](https://github.com/f-aguzzi/tesi/issues/20)


### chore

* **thesis:** set up build system (merge from [#22](https://github.com/f-aguzzi/tesi/issues/22)) ([0b13ed3](https://github.com/f-aguzzi/tesi/commit/0b13ed346448f0eeefecbc6fd051eb7c98919650))


### Refactor

* extract split tests and graphs (merge [#23](https://github.com/f-aguzzi/tesi/issues/23)) ([6865c88](https://github.com/f-aguzzi/tesi/commit/6865c88d70b650de5e8440807b0194022a15dc0e))

## [1.1.0-beta.1](https://github.com/f-aguzzi/tesi/compare/v1.0.0...v1.1.0-beta.1) (2024-05-18)


### Features

* beartype integration ([2f823ce](https://github.com/f-aguzzi/tesi/commit/2f823cebee0cb8006523d9e0d6aaa673484bd928)), closes [#7](https://github.com/f-aguzzi/tesi/issues/7)

## 1.0.0 (2024-05-17)


### ⚠ BREAKING CHANGES

* change package name
* **docs:** moved the `Docusaurus` folder up one level, removed all other documentation (now all inside of Docusaurus subpages)

### Features

* **CI:** automated pylint tests on push ([c794037](https://github.com/f-aguzzi/tesi/commit/c794037807d060b7450e6c720329d69b3cb6f445))
* completed use case diagram ([63ce9e4](https://github.com/f-aguzzi/tesi/commit/63ce9e4744494c7622de7ca52e189a4a6f7768f0))
* **readme:** created readme with badges ([6691d18](https://github.com/f-aguzzi/tesi/commit/6691d1814f23c20376a7e04980375be3bb6f4ce3)), closes [#5](https://github.com/f-aguzzi/tesi/issues/5)
* first draft of project plan ([8adb87d](https://github.com/f-aguzzi/tesi/commit/8adb87d9c4cb66e386c94cf7132601074c541962))
* implemented k-nearest neighbors ([63228a2](https://github.com/f-aguzzi/tesi/commit/63228a26b208bc7e6f4d605aada2cfffbfb87f29)), closes [#12](https://github.com/f-aguzzi/tesi/issues/12)
* **tests:** implemented lldf module unit tests ([9311da4](https://github.com/f-aguzzi/tesi/commit/9311da4c1ba60c5a9d35cc24e9ab70c2c8f58cf4))
* implemented LR class ([ec3582c](https://github.com/f-aguzzi/tesi/commit/ec3582c8941b8db97780504988c2a2b8567285e4)), closes [#2](https://github.com/f-aguzzi/tesi/issues/2)
* implemented pca and lda ([c59147f](https://github.com/f-aguzzi/tesi/commit/c59147f8e349fe93c800e3aa3ef0605263b7950a))
* implemented PLSDA ([af35254](https://github.com/f-aguzzi/tesi/commit/af3525490a9638e608d0bfa8719d90a078d504a8)), closes [#10](https://github.com/f-aguzzi/tesi/issues/10)
* implemented SVM ([a3e95bc](https://github.com/f-aguzzi/tesi/commit/a3e95bc75529fa91ba2f00ef3d78dc3e50a57e89))
* **docs:** move all documentation into docusaurus ([e1f2e7d](https://github.com/f-aguzzi/tesi/commit/e1f2e7dd95354809b2285664798e657d0cef3f8f))
* **docs:** sequence and process UML diagrams ([bec766f](https://github.com/f-aguzzi/tesi/commit/bec766f1cf3d846353b204f254199e771219536d))
* **Colab:** set up notebook for Colab demo ([638a67f](https://github.com/f-aguzzi/tesi/commit/638a67f213b138ad1e48fae3ef06a41f67de35ef)), closes [#4](https://github.com/f-aguzzi/tesi/issues/4)


### Bug Fixes

* **CI/CD:** add missing configuration files ([ebe28d5](https://github.com/f-aguzzi/tesi/commit/ebe28d547ff7c6531f5b3faf365922216a3e76e8))
* **CI:** added conditional activation of workflows ([aa4e916](https://github.com/f-aguzzi/tesi/commit/aa4e91610c9650ab79a9f6df8bd7815170257efc)), closes [#6](https://github.com/f-aguzzi/tesi/issues/6)
* **pylint:** added requirements, increased scores ([bef1cdf](https://github.com/f-aguzzi/tesi/commit/bef1cdfa5839cffbbb908489123ccbcb02459582))
* added test cases for LLDF, PCA, LDA, SVM ([0ba2f26](https://github.com/f-aguzzi/tesi/commit/0ba2f26ba81cf4dae44849730385c0dfabbac73e)), closes [#3](https://github.com/f-aguzzi/tesi/issues/3)
* **CI:** broken rye sync in workflows ([3c8482b](https://github.com/f-aguzzi/tesi/commit/3c8482bcd01191745eb1dba05096520664582701))
* **LLDF:** datasheet export now works properly ([131d3db](https://github.com/f-aguzzi/tesi/commit/131d3db113c9c925223357a4b4b5ea57ee8c6929))
* **CI:** fixed workflow triggers ([6069c89](https://github.com/f-aguzzi/tesi/commit/6069c89676e29c6bf795c2dc8851922a1ad3189a))
* gh_pages workflow ([0a6fc43](https://github.com/f-aguzzi/tesi/commit/0a6fc4373ea18870c47e16d12839462c1ef5fb45))
* **notes:** merged obsidian duplicate folders ([234b200](https://github.com/f-aguzzi/tesi/commit/234b200ecf7a468a72f441a19966621de733c6ac))
* removed pycache, changed favicon ([a6407f6](https://github.com/f-aguzzi/tesi/commit/a6407f662fa286be8bb78d8344cfb73e8f041e8e))
* **CI/CD:** set GitGub token ([05a4440](https://github.com/f-aguzzi/tesi/commit/05a444042d42f3b95dc464f056acd707592d395b)), closes [#15](https://github.com/f-aguzzi/tesi/issues/15)
* **docs:** spelling mistakes ([a10d512](https://github.com/f-aguzzi/tesi/commit/a10d5125d196ebc22304106090ebef6257aa1076))
* **notebook:** update broken links, remove checkpoints ([d8723a1](https://github.com/f-aguzzi/tesi/commit/d8723a1cdc363ccb5ac79692fe4c147225038e95)), closes [#14](https://github.com/f-aguzzi/tesi/issues/14) [#13](https://github.com/f-aguzzi/tesi/issues/13)
* **tests:** various mistakes in workflow script ([3d63d37](https://github.com/f-aguzzi/tesi/commit/3d63d3736bd8eb21da427c4b349d435f21ddae93))


### chore

* change package name ([bd5006d](https://github.com/f-aguzzi/tesi/commit/bd5006d2d1adcc440c4347f945a0a01300f96aa4))
* **rye:** readapt project structure to rye ([38c66e6](https://github.com/f-aguzzi/tesi/commit/38c66e69993510247e6cd3b6f0c75a38f35d341e))
* **testing:** set up automated unit tests ([73b399e](https://github.com/f-aguzzi/tesi/commit/73b399e4b84b6e11ebcf5fdb1601e76b39d5ff97))
* **CI/CD:** set up automatic releases ([8536dc2](https://github.com/f-aguzzi/tesi/commit/8536dc2f26ae66ba658867a7a66c6212ba56dea6))
* **obsidian:** set up devlogs, kanban and uml ([f8ec9af](https://github.com/f-aguzzi/tesi/commit/f8ec9af71809b1bcf5c20f531364ab6dad10b0f4))
* **docs:** set up docusaurus and gh-pages ([3c957e8](https://github.com/f-aguzzi/tesi/commit/3c957e883c2272653b6510d0c8b1094d1edb1ee0))
* set up project structure ([040fcfa](https://github.com/f-aguzzi/tesi/commit/040fcfa8ea804cbd6a63c8a56c41b913f23e87e5))
* set up rye package manager ([f0eefd7](https://github.com/f-aguzzi/tesi/commit/f0eefd7f704313fca892568b0a72fc2340046c44)), closes [#11](https://github.com/f-aguzzi/tesi/issues/11)


### Docs

* add links to project section pages ([9af2786](https://github.com/f-aguzzi/tesi/commit/9af27863d97731f03a9791f9de1e142e2b78f009)), closes [#9](https://github.com/f-aguzzi/tesi/issues/9)
* first draft of requirements specification ([5d1b8c3](https://github.com/f-aguzzi/tesi/commit/5d1b8c34feeb8e57b68e5a9afb3c03ca7e2188ab))
* updated package name in examples ([33f051f](https://github.com/f-aguzzi/tesi/commit/33f051f2e7b13e4c1126235884f3afc83fbcc31c))


### Refactor

* **svm:** added proper kernel validation ([414cda8](https://github.com/f-aguzzi/tesi/commit/414cda8769e6ae886cda3994bf014eccaebfa0ad)), closes [#8](https://github.com/f-aguzzi/tesi/issues/8)
* made project structure PEP-compliant ([b81e925](https://github.com/f-aguzzi/tesi/commit/b81e925df9bcb31977977e422478292bd6d38199))
* upgrade pylint score ([d80e630](https://github.com/f-aguzzi/tesi/commit/d80e630f785d29f7b54bd65794c096bf0723a592))
